SourceInstaller

Trait SourceInstaller 

pub trait SourceInstaller {
    type Error;

    // Required methods
    fn install_module(
        &self,
        config: &CodeGeneratorConfig,
        registry: &Registry,
    ) -> Result<(), Self::Error>;
    fn install_serde_runtime(&self) -> Result<(), Self::Error>;
    fn install_bincode_runtime(&self) -> Result<(), Self::Error>;
    fn install_bcs_runtime(&self) -> Result<(), Self::Error>;
}
How to copy generated source code and available runtimes for a given language.

Required Associated Types

Required Methods

fn install_module( &self, config: &CodeGeneratorConfig, registry: &Registry, ) -> Result<(), Self::Error>

Create a module exposing the container types contained in the registry.

fn install_serde_runtime(&self) -> Result<(), Self::Error>

Install the serde runtime.

fn install_bincode_runtime(&self) -> Result<(), Self::Error>

Install the bincode runtime.

fn install_bcs_runtime(&self) -> Result<(), Self::Error>

Install the Libra Canonical Serialization (BCS) runtime.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl SourceInstaller for serde_generate::cpp::Installer

Source

type Error = Box<dyn Error>

Source

impl SourceInstaller for serde_generate::csharp::Installer

Source

type Error = Box<dyn Error>

Source

impl SourceInstaller for serde_generate::dart::Installer

Source

type Error = Box<dyn Error>

Source

impl SourceInstaller for serde_generate::golang::Installer

Source

type Error = Box<dyn Error>

Source

impl SourceInstaller for serde_generate::java::Installer

Source

type Error = Box<dyn Error>

Source

impl SourceInstaller for serde_generate::kotlin::Installer

Source

type Error = Box<dyn Error>

Source

impl SourceInstaller for serde_generate::ocaml::Installer

Source

type Error = Box<dyn Error>

Source

impl SourceInstaller for serde_generate::python3::Installer

Source

type Error = Box<dyn Error>

Source

impl SourceInstaller for serde_generate::rust::Installer

Source

type Error = Box<dyn Error>

Source

impl SourceInstaller for serde_generate::swift::Installer

Source

type Error = Box<dyn Error>